Format temperature data from VR2AR deployment
ss_compile_vdat_data.RdCompiles and formats temperature and depth data from VR2AR data offloaded in the new .vdat format and exported with Fathom software.
Arguments
- path
File path to the vdat folder. This folder should have one csv file that was extracted using Fathom software. Other file types in the folder will be ignored.
- sn_table
A data frame with three columns:
sensor_type,sensor_serial_number,depth.- deployment_dates
A data frame with two columns. The first column holds the deployment date (a Date object, POSIXct object, or character string in the order year, month, day), and the second column holds the retrieval date (a Date object, POSIXct object, or character string in the order year, month, day).
- trim
Logical value indicating whether to trim the data to the dates specified in
deployment_dates. (Note: four hours are added to the retrieval date to account for AST, e.g., in case the sensor was retrieved after 20:00 AST, which is 00:00 UTC the next day.) Default istrim = TRUE.
Details
The raw VR2AR data must be saved in a folder named vdat in csv format. Folder name is not case-sensitive.
The device timestamp is used here. This may drift over time. Corrected time stamp is included in the .vdat file, but the date is not always appended.